@@ -1,10 +1,8 @@
 #' Train model using [caret::train()].
 #'
-#' @param model_formula Model formula, typically created with `stats::as.formula()`.
 #' @param train_data Training data. Expected to be a subset of the full dataset.
 #' @param cv Cross-validation caret scheme from `define_cv()`.
-#' @param tune_grid Tuning grid from `get_tuning_grid()`.
-#'
+#' @param tune_grid Tuning grid from `get_tuning_grid()`.#'
 #' @inheritParams run_ml
 #'
 #' @return Trained model from [caret::train()].
@@ -28,50 +26,61 @@
 #' tune_grid <- get_tuning_grid(hyperparameters, method)
 #'
 #' rf_model <- train_model(
-#'   stats::as.formula(paste("dx", "~ .")),
 #'   training_data,
+#'   "dx",
 #'   method,
 #'   cross_val,
 #'   "AUC",
 #'   tune_grid,
-#'   1000
+#'   ntree = 1000
 #' )
 #' rf_model$results %>% dplyr::select(mtry, AUC, prAUC)
 #' }
-train_model <- function(model_formula,
-                        train_data,
+train_model <- function(train_data,
+                        outcome_colname,
                         method,
                         cv,
                         perf_metric_name,
                         tune_grid,
-                        ntree) {
+                        ...) {
   withCallingHandlers(
     {
-      if (method == "rf") {
+      if (startsWith(method, "svm")) {
+        # https://github.com/topepo/caret/issues/809#issuecomment-875038420
+        model_formula <- stats::as.formula(paste(outcome_colname, "~ ."))
         trained_model_caret <- caret::train(
-          model_formula,
+          form = model_formula,
           data = train_data,
           method = method,
-          trControl = cv,
           metric = perf_metric_name,
+          trControl = cv,
           tuneGrid = tune_grid,
-          ntree = ntree
+          ...
         )
       } else {
+        features_train <- train_data %>% dplyr::select(-outcome_colname)
+        outcomes_train <-
+          train_data %>% dplyr::pull(outcome_colname)
+        if (is.character(outcomes_train)) {
+          outcomes_train <- outcomes_train %>% as.factor()
+        }
         trained_model_caret <- caret::train(
-          model_formula,
-          data = train_data,
+          x = features_train,
+          y = outcomes_train,
           method = method,
-          trControl = cv,
           metric = perf_metric_name,
-          tuneGrid = tune_grid
+          trControl = cv,
+          tuneGrid = tune_grid,
+          ...
         )
       }
     },
     warning = function(w) {
       if (conditionMessage(w) == "There were missing values in resampled performance measures.") {
         warning(
-          "`caret::train()` issued the following warning:\n \n", w, "\n",
+          "`caret::train()` issued the following warning:\n \n",
+          w,
+          "\n",
           "This warning usually means that the model didn't converge in some cross-validation folds ",
           "because it is predicting something close to a constant. ",
           "As a result, certain performance metrics can't be calculated. ",
