@@ -8,13 +8,18 @@ test_that("flatten_corr_mat works", {
     feature2 = c("b", "c", "c"),
     corr = c(0.8, 0.4, 0)
   )
-  expect_equivalent(expect_warning(flatten_corr_mat(t(data.frame(
-    a = c(1, 0.8, 0.4),
-    b = c(0.8, 1, 0),
-    c = c(0.4, 0, 1)
-  ))), "deprecated"),
-  corr_mat,
-  tolerance = tol
+  expect_warning(
+    expect_equal(
+      flatten_corr_mat(t(data.frame(
+        a = c(1, 0.8, 0.4),
+        b = c(0.8, 1, 0),
+        c = c(0.4, 0, 1)
+      ))),
+      corr_mat,
+      tolerance = tol,
+      ignore_attr = TRUE
+    ),
+    "deprecated"
   )
 })
 
@@ -24,37 +29,39 @@ test_that("get_corr_feats works", {
     feature2 = c("b"),
     corr = c(0.8)
   )
-  expect_equivalent(expect_warning(
+  expect_equal(
     get_corr_feats(data.frame(
       a = c(0.8966972, 0.2655087, 0.37212390, 0.5728534),
       b = c(0.9082078, 0.2016819, 0.89838968, 0.9446753),
       c = c(0.6607978, 0.6291140, 0.06178627, 0.2059746)
     ), 0.6),
-    "deprecated"
-  ),
-  cor_feats,
-  tolerance = tol
-  )
-  expect_equivalent(expect_warning(
+    cor_feats,
+    tolerance = tol,
+    ignore_attr = TRUE
+  ) %>%
+    expect_warning("deprecated") %>%
+    expect_warning("deprecated")
+  expect_equal(
     get_corr_feats(data.frame(
       a = c(0.3607978, 0.2911404, 0.36178627, 0.6059746),
       b = c(0.2099978, 0.3013719, 0.59891969, 0.6442003),
       c = c(0.9066972, 0.6655073, 0.37212390, 0.0728404)
     ), 0.9, corr_method = "pearson"),
-    "deprecated"
-  ),
-  data.frame(
-    feature1 = c("b"),
-    feature2 = c("c"),
-    corr = c(-0.96)
-  ),
-  tolerance = tol
-  )
-  expect_equivalent(expect_warning(get_corr_feats(data.frame(
+    data.frame(
+      feature1 = c("b"),
+      feature2 = c("c"),
+      corr = c(-0.96)
+    ),
+    tolerance = tol,
+    ignore_attr = TRUE
+  ) %>%
+    expect_warning("deprecated") %>%
+    expect_warning("deprecated")
+  expect_equal(get_corr_feats(data.frame(
     a = c(1, 1, 0, 0),
     b = c(1, 1, 0, 0),
     c = c(0, 0, 1, 1)
-  )), "deprecated"),
+  )),
   structure(list(
     feature1 = c("a", "a", "b"), feature2 = c(
       "b",
@@ -65,22 +72,26 @@ test_that("get_corr_feats works", {
     NA,
     -3L
   )),
-  tolerance = tol
-  )
-  expect_equivalent(expect_warning(
+  tolerance = tol,
+  ignore_attr = TRUE
+  ) %>%
+    expect_warning("deprecated") %>%
+    expect_warning("deprecated")
+  expect_equal(
     get_corr_feats(data.frame(
       a = c(1, 1, 0, 0),
       b = c(1, 1, 0, 0),
       c = c(0, 0, 1, 1)
     ), group_neg_corr = FALSE),
-    "deprecated"
-  ),
-  structure(list(feature1 = "a", feature2 = "b", corr = 1), class = "data.frame", row.names = c(
-    NA,
-    -1L
-  )),
-  tolerance = tol
-  )
+    structure(list(feature1 = "a", feature2 = "b", corr = 1), class = "data.frame", row.names = c(
+      NA,
+      -1L
+    )),
+    tolerance = tol,
+    ignore_attr = TRUE
+  ) %>%
+    expect_warning("deprecated") %>%
+    expect_warning("deprecated")
 })
 
 test_that("group_correlated_features works", {
