@@ -1,3 +1,4 @@
+library(dplyr)
 options(
   warnPartialMatchArgs = FALSE,
   warnPartialMatchAttr = FALSE,
@@ -12,12 +13,14 @@ get_all_but_model <- function(ml_results) {
   return(ml_results[names(ml_results) != "trained_model"])
 }
 
-expect_equal_ml_results <- function(result1, result2, tol = 1e-5) {
+expect_equal_ml_results <- function(result1, result2, tolerance = 1e-5) {
   return(
-    eval(bquote(expect_equal(get_all_but_model(result1),
-      get_all_but_model(result2),
-      tolerance = tol
-    )))
+    eval(bquote(
+      expect_equal(get_all_but_model(result1),
+        get_all_but_model(result2),
+        tolerance = tolerance
+      )
+    ))
   )
 }
 
@@ -42,32 +45,37 @@ otu_mini_group <- c(
 
 test_that("run_ml works for logistic regression", {
   expect_equal_ml_results(
-    expect_warning(
-      run_ml(otu_mini_bin, # use built-in hyperparameters
-        "glmnet",
-        outcome_colname = "dx",
-        find_feature_importance = FALSE,
-        seed = 2019,
-        cv_times = 2
-      ),
-      "`caret::train\\(\\)` issued the following warning:"
+    run_ml(
+      otu_mini_bin,
+      # use built-in hyperparameters
+      "glmnet",
+      outcome_colname = "dx",
+      find_feature_importance = FALSE,
+      seed = 2019,
+      cv_times = 2
     ),
     otu_mini_bin_results_glmnet
-  )
+  ) %>%
+    expect_warning("`caret::train\\(\\)` issued the following warning:") %>%
+    suppressMessages()
 })
 
 test_that("run_ml works for linear regression", {
   skip_on_cran()
   expect_equal_ml_results(
-    expect_message(expect_warning(run_ml(otu_mini_bin[, 2:11], # use built-in hyperparameters
+    run_ml(
+      otu_mini_bin[, 2:11], # use built-in hyperparameters
       "glmnet",
       outcome_colname = "Otu00001",
       find_feature_importance = TRUE,
-      seed = 2019,
-      cv_times = 2
-    ), "Data is being considered numeric, but all outcome values are integers. If you meant to code your values as categorical, please use character values.")),
+      cv_times = 2,
+      seed = 2019
+    ),
     otu_mini_cont_results_glmnet
-  )
+  ) %>%
+    expect_warning("Data is being considered numeric") %>%
+    suppressWarnings() %>%
+    suppressMessages()
 })
 
 test_that("run_ml works for random forest with grouping & feature importance", {
@@ -82,22 +90,26 @@ test_that("run_ml works for random forest with grouping & feature importance", {
       groups = otu_mini_group
     ),
     otu_mini_bin_results_rf,
-    tol = 1e-3
-  )
+    tolerance = 1e-3
+  ) %>%
+    suppressWarnings() %>%
+    suppressMessages()
 })
 
 test_that("run_ml works for svmRadial", {
   skip_on_cran()
   expect_equal_ml_results(
-    expect_warning(mikropml::run_ml(otu_mini_bin,
+    mikropml::run_ml(otu_mini_bin,
       "svmRadial",
       outcome_colname = "dx",
       find_feature_importance = FALSE,
       seed = 2019,
       cv_times = 2
-    )),
+    ),
     otu_mini_bin_results_svmRadial
-  )
+  ) %>%
+    expect_warning() %>%
+    suppressMessages()
 })
 
 test_that("run_ml works for xgbTree", {
@@ -113,8 +125,10 @@ test_that("run_ml works for xgbTree", {
       cv_times = 2
     ),
     otu_mini_bin_results_xgbTree,
-    tol = 1e-3
-  )
+    tolerance = 1e-3
+  ) %>%
+    suppressWarnings() %>%
+    suppressMessages()
 })
 
 test_that("run_ml works for rpart2", {
@@ -128,32 +142,36 @@ test_that("run_ml works for rpart2", {
       cv_times = 2
     ),
     otu_mini_bin_results_rpart2
-  )
+  ) %>%
+    suppressMessages()
 })
 
 test_that("run_ml uses a custom cross-validation scheme", {
   skip_on_cran()
   expect_equal_ml_results(
-    expect_message(expect_warning(run_ml(otu_mini_bin[, 2:11],
+    run_ml(otu_mini_bin[, 2:11],
       "glmnet",
       outcome_colname = "Otu00001",
       seed = 2019,
       hyperparameters = list(lambda = c(1e-04), alpha = 0),
       cross_val = caret::trainControl(method = "none"),
       calculate_performance = FALSE
-    ), "Data is being considered numeric, but all outcome values are integers. If you meant to code your values as categorical, please use character values.")),
+    ),
     otu_mini_cont_results_nocv
-  )
+  ) %>%
+    expect_warning("Data is being considered numeric") %>%
+    suppressWarnings() %>%
+    suppressMessages()
 })
 
 test_that("run_ml errors for unsupported method", {
-  expect_error(expect_warning(
-    run_ml(
-      otu_small,
-      "not_a_method"
-    ),
-    "Method 'not_a_method' is not officially supported by mikropml."
-  ), "method 'not_a_method' is not supported.")
+  run_ml(
+    otu_small,
+    "not_a_method"
+  ) %>%
+    expect_warning("Method 'not_a_method' is not officially supported by mikropml") %>%
+    expect_error("method 'not_a_method' is not supported.") %>%
+    suppressMessages()
 })
 
 test_that("run_ml errors if outcome_colname not in dataframe", {
@@ -164,25 +182,26 @@ test_that("run_ml errors if outcome_colname not in dataframe", {
       outcome_colname = "not_a_colname"
     ),
     "Outcome 'not_a_colname' not in column names of data."
-  )
+  ) %>%
+    suppressMessages()
 })
 
 test_that("run_ml works for multiclass outcome", {
   skip_on_cran()
   expect_equal_ml_results(
-    expect_warning(
-      expect_message(run_ml(otu_mini_multi,
-        "glmnet",
-        outcome_colname = "dx",
-        find_feature_importance = TRUE,
-        seed = 2019,
-        cv_times = 2,
-        groups = otu_mini_multi_group
-      ), "Using 'dx' as the outcome column"),
-      "`caret::train\\(\\)` issued the following warning:"
+    run_ml(otu_mini_multi,
+      "glmnet",
+      outcome_colname = "dx",
+      find_feature_importance = TRUE,
+      seed = 2019,
+      cv_times = 2,
+      groups = otu_mini_multi_group
     ),
     otu_mini_multi_results_glmnet
-  )
+  ) %>%
+    expect_message("Using 'dx' as the outcome column") %>%
+    expect_warning("`caret::train\\(\\)` issued the following warning:") %>%
+    suppressMessages()
 })
 
 test_that("run_ml uses custom training indices when provided", {
@@ -198,7 +217,7 @@ test_that("run_ml uses custom training indices when provided", {
       training_frac = training_rows,
       seed = 2019
     )
-  )
+  ) %>% suppressMessages()
   expect_true(dplyr::all_equal(
     results_custom_train$test_data,
     otu_mini_bin[-training_rows, ]
@@ -256,3 +275,39 @@ test_that("models use repeatedcv", {
   expect_equal(otu_mini_bin_results_glmnet$trained_model$control$method, "repeatedcv")
   expect_equal(otu_mini_bin_results_glmnet$trained_model$control$repeats, 2)
 })
+
+test_that("models use case weights when provided", {
+  skip_on_cran()
+  set.seed(20221014)
+  case_weights_dat <- otu_mini_bin %>%
+    count(dx) %>%
+    mutate(p = n / sum(n)) %>%
+    select(dx, p)
+  train_weights <- otu_mini_bin %>%
+    inner_join(case_weights_dat, by = "dx") %>%
+    mutate(
+      in_train = sample(
+        c(TRUE, FALSE),
+        size = nrow(otu_mini_bin),
+        replace = TRUE,
+        prob = c(0.8, 0.2)
+      ),
+      row_num = row_number()
+    ) %>%
+    filter(in_train) %>%
+    select(p, row_num)
+  expect_warning(
+    results_custom_train <- run_ml(
+      otu_mini_bin,
+      "glmnet",
+      kfold = 2,
+      cv_times = 5,
+      training_frac = train_weights %>% pull(row_num),
+      seed = 20221014,
+      weights = train_weights %>% pull(p)
+    ),
+    "simpleWarning in nominalTrainWorkflow"
+  )
+  expect_true("weights" %in% colnames(results_custom_train$trained_model$pred))
+  expect_false("weights" %in% colnames(otu_mini_bin_results_glmnet$trained_model$pred))
+})
